@@ -1,4 +1,5 @@
 from __future__ import annotations
+from contextlib import contextmanager
 from typing import Any, TYPE_CHECKING, Callable, TypeVar, overload, Generic, Union
 from typing_extensions import Literal
 from pathlib import Path
@@ -46,7 +47,6 @@ class MagicField(Field, Generic[_W, _V]):
         default_factory=MISSING,
         metadata: dict[str, Any] = {},
         name: str | None = None,
-        enabled: bool = True,
         record: bool = True,
     ):
         metadata = metadata.copy()
@@ -64,7 +64,6 @@ class MagicField(Field, Generic[_W, _V]):
         self.callbacks: list[Callable] = []
         self.guis: dict[int, _M] = {}
         self.name = name
-        self.enabled = enabled
         self.record = record
 
         # MagicField has to remenber the first class that referred to itself so that it can
@@ -80,13 +79,19 @@ class MagicField(Field, Generic[_W, _V]):
             self.default, self.default_factory, self.metadata, self.name, self.record
         )
 
-    def _resolve_choices(self, obj: Any):
+    @contextmanager
+    def _resolve_choices(self, obj: Any) -> dict[str, Any]:
         """If method is given as choices, get generate method from it."""
         from .gui._base import _is_instance_method, _method_as_getter
 
-        _arg_choices = self.options["choices"]
+        _arg_choices = self.options.get("choices", None)
         if _is_instance_method(obj, _arg_choices):
             self.options["choices"] = _method_as_getter(obj, _arg_choices)
+        try:
+            yield self
+        finally:
+            if _arg_choices is not None:
+                self.options["choices"] = _arg_choices
 
     def get_widget(self, obj: Any) -> _W:
         """
@@ -98,13 +103,11 @@ class MagicField(Field, Generic[_W, _V]):
         if obj_id in self.guis.keys():
             widget = self.guis[obj_id]
         else:
-            if "choices" in self.options:
-                self._resolve_choices(obj)
-            widget = self.to_widget()
-            self.guis[obj_id] = widget
+            with self._resolve_choices(obj):
+                widget = self.to_widget()
+                self.guis[obj_id] = widget
             if self.parent_class is None:
                 self.parent_class = objtype
-            widget.enabled = self.enabled
 
         return widget
 
@@ -118,13 +121,11 @@ class MagicField(Field, Generic[_W, _V]):
         if obj_id in self.guis.keys():
             action = self.guis[obj_id]
         else:
-            if "choices" in self.options:
-                self._resolve_choices(obj)
-            action = self.to_action()
-            self.guis[obj_id] = action
+            with self._resolve_choices(obj):
+                action = self.to_action()
+                self.guis[obj_id] = action
             if self.parent_class is None:
                 self.parent_class = objtype
-            action.enabled = self.enabled
 
         return action
 
@@ -365,7 +366,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[ValueWidget, _X]:
     ...
@@ -378,7 +378,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[_W, Any]:
     ...
@@ -391,7 +390,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[ValueWidget, _X]:
     ...
@@ -404,7 +402,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[_M, Any]:
     ...
@@ -417,7 +414,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[Widget, Any]:
     ...
@@ -429,7 +425,6 @@ def field(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicField[Widget, Any]:
     """
@@ -450,8 +445,6 @@ def field(
         Widget type. This argument will be sent to ``create_widget`` function.
     options : WidgetOptions, optional
         Widget options. This parameter will always be used in ``widget(**options)`` form.
-    enabled : bool, default is True,
-        Set whether widget is initially enabled.
     record : bool, default is True
         Record value changes as macro.
 
@@ -459,7 +452,7 @@ def field(
     -------
     MagicField
     """
-    return _get_field(obj, name, widget_type, options, enabled, record, MagicField)
+    return _get_field(obj, name, widget_type, options, record, MagicField)
 
 
 @overload
@@ -469,7 +462,6 @@ def vfield(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicValueField[ValueWidget, _X]:
     ...
@@ -482,7 +474,6 @@ def vfield(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicValueField[_W, Any]:
     ...
@@ -495,7 +486,6 @@ def vfield(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicValueField[ValueWidget, _X]:
     ...
@@ -508,7 +498,6 @@ def vfield(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicValueField[Widget, Any]:
     ...
@@ -520,7 +509,6 @@ def vfield(
     name: str = "",
     widget_type: str | type[WidgetProtocol] | None = None,
     options: dict[str, Any] = {},
-    enabled: bool = True,
     record: bool = True,
 ) -> MagicValueField[Widget, Any]:
     """
@@ -545,9 +533,6 @@ def vfield(
     widget_type : str, optional
         Widget type. This argument will be sent to ``create_widget`` function.
     options : WidgetOptions, optional
-        Widget options. This parameter will always be used in ``widget(**options)`` form.
-    enabled : bool, default is True,
-        Set whether widget is initially enabled.
     record : bool, default is True
         Record value changes as macro.
 
@@ -555,7 +540,7 @@ def vfield(
     -------
     MagicValueField
     """
-    return _get_field(obj, name, widget_type, options, enabled, record, MagicValueField)
+    return _get_field(obj, name, widget_type, options, record, MagicValueField)
 
 
 def _get_field(
@@ -563,14 +548,15 @@ def _get_field(
     name: str,
     widget_type: str | type[WidgetProtocol] | None,
     options: dict[str, Any],
-    enabled: bool,
     record: bool,
     field_class: type[MagicField],
 ) -> type[MagicField]:
+    if not isinstance(options, dict):
+        raise TypeError(f"Field options must be a dict, got {type(options)}")
     options = options.copy()
     metadata = dict(widget_type=widget_type, options=options)
 
-    kwargs = dict(metadata=metadata, name=name, enabled=enabled, record=record)
+    kwargs = dict(metadata=metadata, name=name, record=record)
     if isinstance(obj, type):
         f = field_class(default_factory=obj, **kwargs)
     elif obj is MISSING:
