@@ -1,8 +1,9 @@
 from __future__ import annotations
 from enum import Enum
 import typing
-from typing import Any, Union, Iterable, overload, TYPE_CHECKING, TypeVar, Callable
-from typing_extensions import Literal, Annotated, ParamSpec
+from typing import Any, Union, Iterable, overload, TypeVar, Callable
+from typing_extensions import Literal, Annotated, ParamSpec, _AnnotatedAlias
+from magicgui.signature import split_annotated_type
 from magicgui.widgets import Widget, EmptyWidget
 
 from .fields import MagicField
@@ -12,9 +13,6 @@ try:
 except ImportError:
     _tp_cache = lambda x: x
 
-if TYPE_CHECKING:
-    from typing_extensions import _AnnotatedAlias
-
 
 class WidgetType(Enum):
     none = "none"
@@ -70,7 +68,8 @@ ErrorModeStr = Union[
     Literal["stdout"],
 ]
 
-Color = Union[str, Iterable[float]]
+Color = Union[Iterable[float], str]
+
 _W = TypeVar("_W", bound=Widget)
 _V = TypeVar("_V", bound=object)
 _P = ParamSpec("_P")
@@ -141,22 +140,6 @@ class _BoundAlias(type):
 
     @_tp_cache
     def __getitem__(cls, value):
-        """
-        Make Annotated type from a MagicField or a method, such as:
-
-        .. code-block:: python
-
-            from magicclass import magicclass, field
-
-            @magicclass
-            class MyClass:
-                i = field(int)
-                def func(self, v: Bound[i]):
-                    ...
-
-        ``Bound[value]`` is identical to ``Annotated[Any, {"bind": value}]``.
-        """
-
         if isinstance(value, tuple):
             raise TypeError(
                 "Bound[...] should be used with only one "
@@ -166,6 +149,22 @@ class _BoundAlias(type):
 
 
 class Bound(metaclass=_BoundAlias):
+    """
+    Make Annotated type from a MagicField or a method, such as:
+
+    .. code-block:: python
+
+        from magicclass import magicclass, field
+
+        @magicclass
+        class MyClass:
+            i = field(int)
+            def func(self, v: Bound[i]):
+                ...
+
+    ``Bound[value]`` is identical to ``Annotated[Any, {"bind": value}]``.
+    """
+
     def __new__(cls, *args):
         raise TypeError(
             "`Bound(...)` is deprecated since 0.5.21. Bound is now a generic alias instead "
@@ -176,44 +175,133 @@ class Bound(metaclass=_BoundAlias):
         raise TypeError(f"Cannot subclass {cls.__module__}.Bound")
 
 
-class Optional:
-    def __new__(cls, *args, **kwargs):
-        raise TypeError("Type Bound cannot be instantiated.")
+_T = TypeVar("_T", bound=type)
 
-    @_tp_cache
-    def __class_getitem__(cls, value) -> _AnnotatedAlias:
-        """
-        Make Annotated type similar to ``typing.Optional``.
 
-        Arguments annotated with ``Optional[int]`` will create a
-        ``OptionalWidget`` with a ``SpinBox`` as an inner widget.
-        Arguments annotated with ``Optional[X, {...}]`` will create a
-        ``OptionalWidget`` with a widget constructed using widget option
-        ``{...}``.
-        """
-        if isinstance(value, tuple):
-            type_, options = value
-        else:
-            type_, options = value, {}
+class _OptionalAlias(type):
+    @overload
+    def __getitem__(cls, value: _T) -> type[typing.Optional[_T]]:
+        ...
 
-        if not isinstance(type_, type):
+    @overload
+    def __getitem__(cls, value: tuple[_T, dict[str, Any]]) -> type[typing.Optional[_T]]:
+        ...
+
+    def __getitem__(cls, value):
+        if not isinstance(value, (type, typing._GenericAlias)):
             raise TypeError(
                 "The first argument of Optional must be a type but "
-                f"got {type(type_)}."
-            )
-        if not isinstance(options, dict):
-            raise TypeError(
-                "The second argument of Optional must be a dict but "
-                f"got {type(options)}."
+                f"got {type(value)}."
             )
         from .widgets import OptionalWidget
 
-        opt = dict(
-            widget_type=OptionalWidget,
-            annotation=type_,
-            options=options,
-        )
-        return Annotated[typing.Optional[type_], opt]
+        opt = dict(widget_type=OptionalWidget)
+        if isinstance(value, _AnnotatedAlias):
+            type0, opt0 = split_annotated_type(value)
+            type_ = typing.Optional[type0]
+            opt.update(annotation=type_, options=opt0)
+            return Annotated[type_, opt]
+        else:
+            opt.update(annotation=typing.Optional[value])
+            return Annotated[typing.Optional[value], opt]
+
+
+class Optional(metaclass=_OptionalAlias):
+    """
+    Make Annotated type similar to ``typing.Optional``.
+
+    Arguments annotated with ``Optional[int]`` will create a
+    ``OptionalWidget`` with a ``SpinBox`` as an inner widget.
+    """
+
+    def __new__(cls, *args, **kwargs):
+        raise TypeError("Type Optional cannot be instantiated.")
 
     def __init_subclass__(cls, *args, **kwargs):
-        raise TypeError(f"Cannot subclass {cls.__module__}.Optional")
+        raise TypeError(f"Cannot subclass {cls.__module__}.Optional.")
+
+
+_S = TypeVar("_S", bound=tuple)
+
+
+class _TupleAlias(type):
+    def __getitem__(cls, value: _S) -> type[_S]:
+        from .widgets import TupleEdit
+
+        opt = dict(
+            widget_type=TupleEdit,
+        )
+        if isinstance(value, _AnnotatedAlias):
+            type0, opt0 = split_annotated_type(value)
+            type_ = typing.Tuple[type0]
+            opt.update(annotation=type_, **opt0)
+            return Annotated[typing.Optional[type0], opt0]
+        else:
+            type_ = typing.Tuple[value]
+            opt.update(annotation=type_)
+            return Annotated[type_, opt]
+
+
+class Tuple(metaclass=_TupleAlias):
+    """
+    Make Annotated type similar to ``typing.Tuple``.
+
+    Arguments annotated with ``Tuple[...]`` will create a
+    ``TupleEdit`` with a annotated sub types.
+    """
+
+    def __new__(cls, *args, **kwargs):
+        raise TypeError("Type Tuple cannot be instantiated.")
+
+    def __init_subclass__(cls, *args, **kwargs):
+        raise TypeError(f"Cannot subclass {cls.__module__}.Tuple.")
+
+
+class _ListAlias(type):
+    def __getitem__(cls, value: _T) -> type[list[_T]]:
+        from .widgets import ListEdit
+
+        type_ = typing.List[value]
+        opt = dict(
+            widget_type=ListEdit,
+            annotation=type_,
+        )
+        return Annotated[type_, opt]
+
+
+class List(metaclass=_ListAlias):
+    """
+    Make Annotated type similar to ``typing.List``.
+
+    Arguments annotated with ``List[...]`` will create a
+    ``ListEdit`` with a annotated sub types.
+    """
+
+    def __new__(cls, *args, **kwargs):
+        raise TypeError("Type List cannot be instantiated.")
+
+    def __init_subclass__(cls, *args, **kwargs):
+        raise TypeError(f"Cannot subclass {cls.__module__}.List.")
+
+
+"""
+Examples
+--------
+
+from magicclass import magicclass, set_options
+from magicclass.types import Tuple, List, Optional
+@magicclass
+class A:
+    @set_options(a={"options": {"min": -1}})
+    def f(self, a: Tuple[int, int]):
+        print(a)
+    @set_options(a={"options": {"min": -1}})
+    def g(self, a: List[float]):
+        print(a)
+    @set_options(a={"options": {"min": -1}})
+    def h(self, a: Optional[int]):
+        print(a)
+ui = A()
+ui.show()
+
+"""
