@@ -4,8 +4,7 @@ import inspect
 from typing import Callable, Iterable, Iterator, Union, TYPE_CHECKING, TypeVar, overload
 from typing_extensions import ParamSpec
 import warnings
-from magicgui.widgets import Label
-from macrokit import Expr
+from .utils import show_messagebox
 
 from .types import Color
 from .signature import upgrade_signature
@@ -20,6 +19,7 @@ nStrings = Union[str, Iterable[str]]
 P = ParamSpec("P")
 R = TypeVar("R")
 T = TypeVar("T")
+F = TypeVar("F", bound=Callable)
 
 
 def set_options(
@@ -28,7 +28,7 @@ def set_options(
     call_button: bool | str | None = None,
     auto_call: bool = False,
     **options,
-) -> Callable[[Callable[P, R]], Callable[P, R]]:
+) -> Callable[[F], F]:
     """
     Set MagicSignature to functions.
 
@@ -67,7 +67,7 @@ def set_options(
         Parameter options.
     """
 
-    def wrapper(func: Callable[P, R]) -> Callable[P, R]:
+    def wrapper(func: F) -> F:
         sig = inspect.signature(func)
         rem = options.keys() - sig.parameters.keys()
         if rem:
@@ -150,7 +150,7 @@ def set_design(
         ...
 
     @overload
-    def wrapper(obj: Callable[P, R]) -> Callable[P, R]:
+    def wrapper(obj: F) -> F:
         ...
 
     def wrapper(obj):
@@ -224,13 +224,13 @@ def click(
     return wrapper
 
 
-def do_not_record(method: Callable[P, R]) -> Callable[P, R]:
+def do_not_record(method: F) -> F:
     """Wrapped method will not be recorded in macro."""
     upgrade_signature(method, additional_options={"record": False})
     return method
 
 
-def bind_key(*key) -> Callable[[Callable[P, R]], Callable[P, R]]:
+def bind_key(*key) -> Callable[[F], F]:
     """
     Define a keybinding to a button or an action.
     This function accepts several styles of shortcut expression.
@@ -244,60 +244,123 @@ def bind_key(*key) -> Callable[[Callable[P, R]], Callable[P, R]]:
     if isinstance(key[0], tuple):
         key = key[0]
 
-    def wrapper(
-        method: Callable[P, R],
-    ) -> Callable[P, R]:
+    def wrapper(method: F) -> F:
         upgrade_signature(method, additional_options={"keybinding": key})
         return method
 
     return wrapper
 
 
-def confirm(text: str, call_button_text: str = "OK"):
+class Canceled(RuntimeError):
+    """Raised when a function is canceled"""
+
+
+@overload
+def confirm(
+    *,
+    text: str | None,
+    condition: Callable[P, bool] | str | None,
+) -> Callable[[F], F]:
+    ...
+
+
+@overload
+def confirm(
+    f: F,
+    *,
+    text: str | None,
+    condition: Callable[P, bool] | str | None,
+) -> F:
+    ...
+
+
+def confirm(
+    f: F | None = None,
+    *,
+    text: str | None = None,
+    condition: Callable[[BaseGui], bool] | str = None,
+):
     """
-    Confirm if it is OK to run function in GUI. Useful when the function will irreversibly
-    delete or update something in GUI.
+    Confirm if it is OK to run function in GUI.
+
+    Useful when the function will irreversibly delete or update something in GUI.
+    Confirmation will be executed only when function is called in GUI.
 
     Parameters
     ----------
-    text : str
-        Confirmation text, such as "Are you sure to run this function?".
-    call_button_text : str, default is "OK"
-        Text shown on the call button.
+    text : str, optional
+        Confirmation message, such as "Are you sure to run this function?". Format
+        string can also be used here, in which case arguments will be passed. For
+        instance, to execute confirmation on function ``f(a, b)``, you can use
+        format string ``"Running with a = {a} and b = {b}"`` then confirmation
+        message will be "Running with a = 1, b = 2" if ``f(1, 2)`` is called.
+        By default, message will be "Do you want to run {name}?" where "name" is
+        the function name.
+    condition : callable or str, optional
+        Condition of when confirmation will show up. If callable, it must accept
+        ``condition(self)`` and return boolean object. If string, it must be
+        evaluable as literal with input arguments as local namespace. For instance,
+        function ``f(a, b)`` decorated by ``confirm(condition="a < b + 1")`` will
+        evaluate ``a < b + 1`` to check if confirmation is needed. Always true by
+        default.
     """
-    if not isinstance(text, str):
-        raise TypeError(
-            f"The first argument of 'confirm' must be a str bug got {type(text)}"
-        )
+    if condition is None:
+        condition = lambda x: True
 
-    def _decorator(method: Callable[P, R]) -> Callable[P, R]:
-        sig = inspect.signature(method)
-        if len(sig.parameters) != 1:
-            raise ValueError(
-                "Currently 'confirm' only supports methods that take no argument."
+    def _decorator(method: F) -> F:
+        _name = method.__name__
+
+        # set text
+        if text is None:
+            _text = f"Do you want to run {_name}?"
+        elif isinstance(text, str):
+            _text = text
+        else:
+            raise TypeError(
+                f"The first argument of 'confirm' must be a str but got {type(text)}."
             )
 
-        @do_not_record
-        @set_options(
-            call_button=call_button_text,
-            labels=False,
-            label={"widget_type": Label, "value": text},
-        )
-        def _method(self: BaseGui, label=None):
-            out = method(self)
-            expr = Expr.parse_method(self, method, (), {})
-            self.macro.append(expr)
-            return out
+        sig = inspect.signature(method)
 
-        _method.__name__ = method.__name__
-        _method.__qualname__ = method.__qualname__
-        _method.__module__ = method.__module__
+        @wraps(method)
+        def _method(self: BaseGui, *args, **kwargs):
+            if self[_name].running:
+                arguments = sig.bind(self, *args, **kwargs)
+                arguments.apply_defaults()
+                all_args = arguments.arguments
+                need_confirmation = False
+                if isinstance(condition, str):
+                    need_confirmation = eval(condition, {}, all_args)
+                elif callable(condition):
+                    need_confirmation = condition(self)
+                else:
+                    warnings.warn(
+                        f"Condition {condition} should be callable or string but got type "
+                        f"{type(condition)}. No confirmation was executed.",
+                        UserWarning,
+                    )
+                if need_confirmation:
+                    ok = show_messagebox(
+                        mode="question",
+                        title="Confirmation",
+                        text=_text.format(**all_args),
+                        parent=self.native,
+                    )
+                    if not ok:
+                        raise Canceled("Canceled")
+
+            return method(self, *args, **kwargs)
+
+        if hasattr(method, "__signature__"):
+            _method.__signature__ = method.__signature__
         return _method
 
+    if f is not None:
+        _decorator(f)
     return _decorator
 
 
-def nogui(method: Callable[P, R]) -> Callable[P, R]:
+def nogui(method: F) -> F:
     """Wrapped method will not be converted into a widget."""
     upgrade_signature(method, additional_options={"gui": False})
     return method
